@@ -84,7 +84,7 @@ QAbstractItemModel *WorkdayPageModel::createCentralListModel()
     };
 
     auto fetchAdditionalInfo = [this](const QModelIndex &index, const Domain::Task::Ptr &task) {
-        return fetchTaskExtraData(m_taskQueries, TaskExtraPart::Project, index, task);
+        return fetchTaskExtraData(m_taskQueries, TaskExtraPart::Project | TaskExtraPart::Contexts, index, task);
     };
 
     auto setData = [this](const Domain::Task::Ptr &task, const QVariant &value, int role) {
